==> janis-pipelines.bioinformatics-0.10.3.tar.gz: janis-pipelines.bioinformatics-0.10.3/janis_bioinformatics/tools/pmac/addBamStatsGermlineWorkflow.py <==
from janis_core import WorkflowBuilder, WorkflowMetadata

# data types
from janis_bioinformatics.data_types import Vcf, BamBai

from janis_core import String

from janis_bioinformatics.tools import BioinformaticsWorkflow

from janis_bioinformatics.tools.bioinformaticstoolbase import (
    BioinformaticsWorkflowBuilder,
)
from janis_bioinformatics.tools.pmac import AddBamStatsLatest
from janis_bioinformatics.tools.samtools import SamToolsMpileupLatest


class AddBamStatsGermline_0_1_0(BioinformaticsWorkflow):
    def id(self) -> str:
        return "AddBamStatsGermline"

    def friendly_name(self):
        return "Annotate Bam Stats to Germline Vcf Workflow"

    def tool_provider(self):
        return "Peter MacCallum Cancer Centre"

    def bind_metadata(self):
        return WorkflowMetadata(version="v0.1.0", contributors=["Jiaan Yu"])

    def constructor(self):

        # self.input("sample_name", String)
        self.input("bam", BamBai)
        self.input("vcf", Vcf)

        self.step(
            "samtoolsmpileup",
            SamToolsMpileupLatest(
                bam=self.bam,
                positions=self.vcf,
                countOrphans=True,
                noBAQ=True,
                minBQ=0,
                maxDepth=10000,
            ),
        )

        self.step(
            "addbamstats",
            AddBamStatsLatest(
                inputVcf=self.vcf, mpileup=self.samtoolsmpileup.out, type="germline",
            ),
        )

        self.output("out", source=self.addbamstats.out, output_name="addbasmtats.vcf")

==> janis-pipelines.bioinformatics-0.11.0.tar.gz: janis-pipelines.bioinformatics-0.11.0/janis_bioinformatics/tools/pmac/addBamStatsGermlineWorkflow.py <==
from datetime import datetime
from janis_core import WorkflowBuilder, WorkflowMetadata

# data types
from janis_bioinformatics.data_types import Vcf, BamBai
from janis_bioinformatics.data_types import FastaWithDict

from janis_core import String

from janis_bioinformatics.tools import BioinformaticsWorkflow

from janis_bioinformatics.tools.bioinformaticstoolbase import (
    BioinformaticsWorkflowBuilder,
)
from janis_bioinformatics.tools.pmac import AddBamStatsLatest
from janis_bioinformatics.tools.samtools import SamToolsMpileupLatest


class AddBamStatsGermline_0_1_0(BioinformaticsWorkflow):
    def id(self) -> str:
        return "AddBamStatsGermline"

    def friendly_name(self):
        return "Annotate Bam Stats to Germline Vcf Workflow"

    def tool_provider(self):
        return "Peter MacCallum Cancer Centre"

    def bind_metadata(self):
        return WorkflowMetadata(
            version="v0.1.0",
            contributors=["Jiaan Yu"],
            dateCreated=datetime(2020, 6, 4),
            dateUpdated=datetime(2020, 8, 10),
        )

    def constructor(self):

        # self.input("sample_name", String)
        self.input("bam", BamBai)
        self.input("vcf", Vcf)
        self.input("reference", FastaWithDict)

        self.step(
            "samtoolsmpileup",
            SamToolsMpileupLatest(
                bam=self.bam,
                positions=self.vcf,
                reference=self.reference,
                countOrphans=True,
                noBAQ=True,
                minBQ=0,
                maxDepth=10000,
            ),
        )

        self.step(
            "addbamstats",
            AddBamStatsLatest(
                inputVcf=self.vcf, mpileup=self.samtoolsmpileup.out, type="germline",
            ),
        )

        self.output("out", source=self.addbamstats.out, output_name="addbasmtats.vcf")
